@@ -14,7 +14,7 @@ use utf8;
 ## use critic (Modules::RequireExplicitPackage)
 
 package Sys::OsPackage::Driver::RPM;
-$Sys::OsPackage::Driver::RPM::VERSION = '0.2.0';
+$Sys::OsPackage::Driver::RPM::VERSION = '0.3.0';
 use base "Sys::OsPackage::Driver";
 
 # check if packager command found (rpm)
@@ -35,8 +35,8 @@ sub modpkg
     my @querycmd = ((defined $ospkg->sysenv("dnf"))
         ? ($ospkg->sysenv("dnf"), "repoquery")
         : $ospkg->sysenv("repoquery"));
-    my @pkglist = sort $ospkg->capture_cmd({list=>1}, @querycmd, qw(--available --quiet --whatprovides),
-        "'perl(".$args_ref->{module}.")'");
+    my @pkglist = sort $ospkg->capture_cmd({list=>1}, $ospkg->sudo_cmd(), @querycmd,
+        qw(--available --quiet --whatprovides), "'perl(".$args_ref->{module}.")'");
     $ospkg->debug()
         and print STDERR "debug(".__PACKAGE__."->modpkg): ".$args_ref->{module}." -> ".join(" ", @pkglist)."\n";
     return if not scalar @pkglist; # empty list means nothing found
@@ -52,7 +52,8 @@ sub find
     my @querycmd = ((defined $ospkg->sysenv("dnf"))
         ? ($ospkg->sysenv("dnf"), "repoquery")
         : $ospkg->sysenv("repoquery"));
-    my @pkglist = sort $ospkg->capture_cmd({list=>1}, @querycmd, qw(--quiet --latest-limit=1), $args_ref->{pkg});
+    my @pkglist = sort $ospkg->capture_cmd({list=>1}, $ospkg->sudo_cmd(), @querycmd, qw(--quiet --latest-limit=1),
+        $args_ref->{pkg});
     return if not scalar @pkglist; # empty list means nothing found
     return $pkglist[-1]; # last of sorted list should be most recent version
 }
@@ -75,7 +76,8 @@ sub install
 
     # install the packages
     my $pkgcmd = (defined $ospkg->sysenv("dnf")) ? $ospkg->sysenv("dnf") : $ospkg->sysenv("yum");
-    return $ospkg->run_cmd($pkgcmd, qw(install --quiet --assumeyes --setopt=install_weak_deps=false), @packages);
+    return $ospkg->run_cmd($ospkg->sudo_cmd(), $pkgcmd,
+        qw(install --quiet --assumeyes --setopt=install_weak_deps=false), @packages);
 }
 
 # check if an OS package is installed locally
@@ -86,7 +88,7 @@ sub is_installed
 
     # check if package is installed
     my $querycmd = $ospkg->sysenv("rpm");
-    my @pkglist = $ospkg->capture_cmd({list=>1}, $querycmd, qw(--query), $args_ref->{pkg});
+    my @pkglist = $ospkg->capture_cmd({list=>1}, $ospkg->sudo_cmd(), $querycmd, qw(--query), $args_ref->{pkg});
     return (scalar @pkglist > 0) ? 1 : 0;
 }
 
@@ -102,7 +104,7 @@ Sys::OsPackage::Driver::RPM - RedHat/Fedora RPM packaging handler for Sys::OsPac
 
 =head1 VERSION
 
-version 0.2.0
+version 0.3.0
 
 =head1 SYNOPSIS
 
